import { type PathLike } from 'fs';
export interface RenderedContent {
    html: string;
    metadata?: Record<string, unknown>;
}
export interface DataEntry {
    id: string;
    data: Record<string, unknown>;
    filePath?: string;
    body?: string;
    digest?: number | string;
    rendered?: RenderedContent;
}
export declare class DataStore {
    #private;
    constructor();
    get<T = unknown>(collectionName: string, key: string): T | undefined;
    entries<T = unknown>(collectionName: string): Array<[id: string, T]>;
    values<T = unknown>(collectionName: string): Array<T>;
    keys(collectionName: string): Array<string>;
    set(collectionName: string, key: string, value: unknown): void;
    delete(collectionName: string, key: string): void;
    clear(collectionName: string): void;
    has(collectionName: string, key: string): boolean;
    hasCollection(collectionName: string): boolean;
    collections(): Map<string, Map<string, any>>;
    scopedStore(collectionName: string): ScopedDataStore;
    metaStore(collectionName: string): MetaStore;
    toString(): string;
    writeToDisk(filePath: PathLike): Promise<void>;
    static fromDisk(filePath: PathLike): Promise<DataStore>;
    static fromString(str: string): DataStore;
    static fromModule(): Promise<DataStore>;
    static fromJSON(entries: Array<[string, Array<[string, any]>]>): DataStore;
}
export interface ScopedDataStore {
    get: (key: string) => DataEntry | undefined;
    entries: () => Array<[id: string, DataEntry]>;
    set: (opts: {
        id: string;
        data: Record<string, unknown>;
        body?: string;
        filePath?: string;
        digest?: number | string;
        rendered?: RenderedContent;
    }) => boolean;
    values: () => Array<DataEntry>;
    keys: () => Array<string>;
    delete: (key: string) => void;
    clear: () => void;
    has: (key: string) => boolean;
}
/**
 * A key-value store for metadata strings. Useful for storing things like sync tokens.
 */
export interface MetaStore {
    get: (key: string) => string | undefined;
    set: (key: string, value: string) => void;
    has: (key: string) => boolean;
    delete: (key: string) => void;
}
export declare const globalDataStore: {
    get: () => Promise<DataStore>;
    set: (store: DataStore) => void;
};
